﻿using System;
using System.Drawing;
using System.Windows.Forms;

using Steema.TeeChart;
using Steema.TeeChart.Animations;
using Steema.TeeChart.Animations.EasingFunctions;
using Steema.TeeChart.Drawing;
using Steema.TeeChart.Editors;
using Steema.TeeChart.Editors.Animations;
using Steema.TeeChart.Styles;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 차트 파트 애니메이션
        /// </summary>
        private ChartPartAnimation chartPartAnimation;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            Text = "ChartPartAnimation 클래스 : 차트 애니메이션 사용하기";

            this.tChart.Panel.Pen = new ChartPen(Color.Black);

            Bar bar = new Bar(this.tChart.Chart);

            bar.Marks.Clip = true;

            bar.FillSampleValues();

            this.chartPartAnimation = new ChartPartAnimation(this.tChart.Chart);

            this.chartPartAnimation.Series         = bar;
            this.chartPartAnimation.EasingFunction = new BounceEase();
            this.chartPartAnimation.EasingMode     = EasingMode.EaseOut;
            this.chartPartAnimation.Target         = ChartClickedPartStyle.Series;
            this.chartPartAnimation.TranslateStyle = TransformTranslate.FromLeft;

            this.runButton.Click  += runButton_Click;
            this.editButton.Click += editButton_Click;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 실행 버튼 클릭시 처리하기 - runButton_Click(sender, e)

        /// <summary>
        /// 실행 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void runButton_Click(object sender, EventArgs e)
        {
            this.chartPartAnimation.Play();
        }

        #endregion
        #region 편집 버튼 클릭시 처리하기 - editButton_Click(sender, e)

        /// <summary>
        /// 편집 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void editButton_Click(object sender, EventArgs e)
        {
            ChartPartEditor chartPartEditor = new ChartPartEditor(this.chartPartAnimation);

            EditorUtils.ShowFormModal(chartPartEditor);
        }

        #endregion
    }
}